=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2007-02-13 05:22:39 +0000
+++ bzrlib/option.py	2007-03-02 04:53:10 +0000
@@ -227,7 +227,7 @@
             return self.converter(value)
 
     def __init__(self, name, help, registry, converter=None,
-        value_switches=False, title=None):
+        value_switches=False, title=None, enum_switch=True):
         """
         Constructor.
 
@@ -239,12 +239,15 @@
         :param value_switches: If true, each possible value is assigned its
             own switch.  For example, instead of '--format knit',
             '--knit' can be used interchangeably.
+        :param enum_switch: If true, a switch is provided with the option name,
+            which takes a value.
         """
         Option.__init__(self, name, help, type=self.convert)
         self.registry = registry
         self.name = name
         self.converter = converter
         self.value_switches = value_switches
+        self.enum_switch = enum_switch
         self.title = title
         if self.title is None:
             self.title = name
@@ -253,7 +256,8 @@
         """Add this option to an Optparse parser"""
         if self.value_switches:
             parser = parser.add_option_group(self.title)
-        Option.add_option(self, parser, short_name)
+        if self.enum_switch:
+            Option.add_option(self, parser, short_name)
         if self.value_switches:
             for key in self.registry.keys():
                 option_strings = ['--%s' % key]

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2007-02-14 07:10:27 +0000
+++ bzrlib/tests/test_options.py	2007-03-02 04:53:10 +0000
@@ -157,6 +157,10 @@
         opts, args = self.parse(options, ['--two', '--one',
                                           '--format', 'two'])
         self.assertEqual({'format':'two'}, opts)
+        options = [option.RegistryOption('format', '', registry, str,
+                   enum_switch=False)]
+        self.assertRaises(errors.BzrCommandError, self.parse, options,
+                          ['--format', 'two'])
 
     def test_registry_converter(self):
         options = [option.RegistryOption('format', '',

